==> voxstorm-0.3.3.tar.bz2: voxstorm-0.3.3/src/cecaiamanager.h <==
/***************************************************************************/
/*! \file   cecaiamanager.h
    \brief  饹CEcaIAManagerΥإåե롣
    \author Tomoaki Murakami
    \date   2004ǯ  5  4  17:35:12 JST
*/
/***************************************************************************/

/***************************************************************************
 *   Copyright (C) 2004 by Tomoaki Murakami                                *
 *   solarisphrere@yahoo.co.jp                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef CECAIAMANAGER_H
#define CECAIAMANAGER_H

#include <qvaluevector.h>
#include <qdatetime.h>
#include "ctrackinf.h"
#include "csourceformat.h"
#include "cecaiacontroller.h"

/*-------------------------------------------------------------------------*/
/*! \class  CEcaIAManager
    \brief  VoxStormΥ󥸥
*/
/*-------------------------------------------------------------------------*/
class CEcaIAManager : public CEcaIAController
{
  Q_OBJECT

public:
  enum RunningStatus {
    NotRunning,
    Playing,
    Recording,
    Mixing
  };

  //! \brief 󥹥ȥ饯
  CEcaIAManager();
  //! \brief ǥȥ饯
  virtual ~CEcaIAManager();

  //! \brief  Ծ֤֤
  //! \return Ծ֡
  RunningStatus runningStatus() const;
  //! \brief  ꤵ줿ȥå̾Τ˥󥻥åȥåפ¸ߤ뤫ɤ֤
  //! \param  strTrackName ȥå̾Ρ
  //! \return ¸ߤƤ硢true֤
  bool isExisting(const QString& strTrackName) const;
  //! \brief  ꤵƤϤο֤
  //! \return Ϥο
  int numberOfInputs();
  //! \brief  ꤵƤϤο֤
  //! \return Ϥο
  int numberOfOutputs();
  //! \brief  Ͽ֤
  CSourceFormat soundSourceFormat() const;
  //! \brief  Хåե֤
  int bufferSize() const;
  //! \brief  Ͽꤹ롣
  void setSoundSourceFormat(const CSourceFormat& format);
  //! \brief  Хåեꤹ롣
  void setBufferSize(int nSize);
  //! \brief  ֤֤߰
  QTime pos();

public slots:
  //! \brief 󥻥åȥåפ򿷵롣
  //! \param strChainsetup 󥻥åȥå̾Ρ
  void slotCreateNewChainsetup(const QString& strChainsetup);
  //! \brief 󥻥åȥåפ˴롣
  void slotReleaseCurrentChainsetup();

  //! \brief 
  //! \param bRecord ϿꤵƤtrueꡣ
  void slotPlay(bool bRecord);
  //! \brief ߡ
  void slotStop();
  //! \brief ߡ
  void slotPause();
  //! \brief ߲
  void slotResume();
  //! \brief ޥݥѹ롣
  //! \param time ְ֡
  void slotSetMasterPosition(const QTime& time);
  //! \brief ֤ذư
  //! \param nSec ð֡
  void slotSetMasterPosition(int nSec);
  //! \brief ÿ󥻥åȥåפ᤹
  //! \param nSecond ᤷÿ
  void slotRewind(int nSecond);
  //! \brief ÿ󥻥åȥåפꤹ롣
  //! \param nSecond ꤷÿ
  void slotForward(int nSecond);
  //! \brief ߥå
  //! \param bWithPlaying ʤߥå󤹤trueꡣ
  //! \param strChainsetup ߥåѥ󥻥åȥå̾Ρ
  //! \param strFileName ߥåե̾Ρ
  void slotMixdown(bool bWithPlaying, 
                   const QString& strChainsetup, 
                   const QString& strFileName);

  //! \brief ȥåȤɲä롣
  //! \param TrackInfAdd Ȥɲäȥå
  void slotAddChain(const CTrackInf& TrackInfAdd);
  //! \brief 롣
  //! \param strTrackName ȥå̾Ρ
  void slotRemoveChain(const QString& strTrackName);
  //! \brief 롣
  //! \param nID ȥåID
  void slotRemoveChain(int nID);
  //! \brief ƤΥ롣
  void slotRemoveAllChains();
  //! \brief ƤϤ롣
  void slotRemoveAllInputs();
  //! \brief ƤνϤ롣
  void slotRemoveAllOutputs();

  //! \brief ץ쥤ХåǥХѹ
  void slotChangePlaybackDevice(const QString& strTrackName,
                                const QString& strDevice);
  //! \brief 쥳ǥ󥰥ǥХѹ
  void slotChangeRecordingDevice(const QString& strTrackName,
                                 const QString& strDevice);
  //! \brief ե̾ѹ
  void slotChangeFileName(const QString& strTrackName, const QString& strFileName);
  //! \brief ٥ѹ
  void slotChangeLevel(const QString& strTrackName, int nLevel);
  //! \brief ѥѹ
  void slotChangePan(const QString& strTrackName, int nPan);
  //! \brief ߥ塼Ⱦѹ
  void slotToggleMute(const QString& strTrackName, bool bMute);
  //! \brief Ͽѹ
  void slotToggleRec(const QString& strTrackName, bool bRec);
  //! \brief ϰѹ
  void slotChangeStartPosition(const QString& strTrackName, const QTime& StartPosition);
  //! \brief եåѹ
  void slotChangeOffset(const QString& strTrackName, const QTime& Offset);
  //! \brief Ĺѹ
  void slotChangeLength(const QString& strTrackName, const QTime& Length);

private:
  //! \brief ԡ󥹥ȥ饯ԡػߤ뤿ᡢprivate
  CEcaIAManager(const CEcaIAManager&);
  //! \brief 黻ҡػߤ뤿ᡢprivate
  CEcaIAManager& operator=(const CEcaIAManager&);

  //! ȥå٥
  QValueVector<CTrackInf> vTrackChains;
  //! Ewfѥȥå٥
  QValueVector<CTrackInf> vPrepareTrackChains;
  //! IDEcasoundλ(Finished)Ƚ˻ѡ
  int nTimerIDFinished;
  //! IDּ߰˻ѡ
  int nTimerIDCurrentPos;
  //! ޥݥ(ϰ())
  int nMasterPosition;
  //! ե̾Υꥹȡ
  QStringList strlTmpFiles;
  //! Ծ
  RunningStatus rStatus;
  //! Ͽեޥå
  CSourceFormat formatRecording;
  //! Хåե
  int           nBufferSize;

  //! \brief ȥå̾ΤФȥåΥǥ֤
  //! ꤵ줿ȥå̾ΤФȥå󤬸Ĥʤ硢
  //! -1֤롣
  //! \param strTrackName ȥå̾Ρ
  int getIndexByName(const QString& strTrackName) const;
  //! \brief ϥեȥǥХEcaControlerꤹ롣
  //! \param bRecord 쥳ǥ󥰤ͭˤʤäƤtrueꡣ
  //! \todo  too heavy
  //! ʣΥɥǥХбɬפ롣
  void setIOToCurrentChainsetup(bool bRecord);
  //! \brief ߥåѤEcaControlerꤹ롣
  //! \param bWithPlaying ʤߥå󤹤trueꡣ
  //! \param strFileName ߥåե̾Ρ
  void setMixdownIOToCurrentChainsetup(bool bWithPlaying, const QString& strFileName);
  //! \brief ޥ٥ȡ
  //! Ecasoundκλ(Finished)Ƚꤹ뤿Υޥ٥ȡ
  //! EcasoundΥץ֤Ƚꤹ뤿Υޥ٥ȡ
  void timerEvent(QTimerEvent* TimerEvent);
  //! \brief .ewfե롣
  //! \param strTrackName ȥå̾Ρ
  //! \param strFileName ե̾Ρ
  void writeEwf(const QString& strTrackName, const QString& strFileName);
  //! \brief .ewfե롣
  //! \param nIndex ȥåǥ
  //! \param strFileName ե̾Ρ
  void writeEwf(int nIndex, const QString& strFileName);
  //! \brief ȥåФɬפ.ewfեνԤ
  //! ȥåνԤ줿ȥåvPrepareTrackChains
  //! ˳Ǽ롣
  //! setIOToCurrentChainsetupΤ߸ƤӽФġ
  //! \param bIgnoresRecord ƥȥåΥ쥳ǥ󥰥ե饰̵뤹롣
  //! ߥåϡtrueꤹ롣
  //! \todo ߤϡΥȥåvPrepareTrackChains˳ǼƤ롣
  //! setIOToCurrentChainsetupvPrepareTrackChains
  //! Ȥ褦ˤ̵̤ʤʤ롣
  //! 硢vPrepareTrackChainsˤϡΤǤϤʤ
  //! EwfѤΥȥåǼФ褤
  void prepareTracks(bool bIgnoresRecord=false);
  //! \brief ȥå˹Ԥä.ewfեν򸵤᤹
  //! setIOToCurrentChainsetupΤ߸ƤӽФġ
  //! \todo setIOToCurrentChainsetupvPrepareTrackChains
  //! Ȥ褦ˤ餳δؿɬפʤʤ롣
  void destroyPreparings();
  //! \brief ƥݥե롣
  void removeTmpFiles();
  //! \brief ߤ
  void doDetailStopped();

private slots:
  //! \brief 
  //! \param strTrackName 򤷤ȥå̾Ρ
  //! ʣ򤷤硢','Ƕڤ롣
  void slotSelectChain(const QString& strTrackName);

signals:
  //! \brief ޥݥѹ줿ȯ륷ʥ롣
  void masterPositionChanged(const QTime&);
  //! \brief Ecasoundξ֤Finishedˤʤäȯ륷ʥ롣
  //! Stopped֤ˤʤäƤȯʤ
  void finished();
  //! \brief ˸֤߰Τ餻뤿ȯ륷ʥ롣
  void moved(const QTime&);
};

#endif

==> voxstorm-0.3.5.tar.bz2: voxstorm-0.3.5/src/cecaiamanager.h <==
/***************************************************************************/
/*! \file   cecaiamanager.h
    \brief  饹CEcaIAManagerΥإåե롣
    \author Tomoaki Murakami
    \date   2004ǯ  5  4  17:35:12 JST
*/
/***************************************************************************/

/***************************************************************************
 *   Copyright (C) 2004 by Tomoaki Murakami                                *
 *   solarisphrere@yahoo.co.jp                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef CECAIAMANAGER_H
#define CECAIAMANAGER_H

#include <qvaluevector.h>
#include <qdatetime.h>
#include "ctrackinf.h"
#include "csourceformat.h"
#include "cecaiacontroller.h"

/*-------------------------------------------------------------------------*/
/*! \class  CEcaIAManager
    \brief  VoxStormΥ󥸥
*/
/*-------------------------------------------------------------------------*/
class CEcaIAManager : public CEcaIAController
{
  Q_OBJECT

public:
  enum RunningStatus {
    NotRunning,
    Playing,
    Recording,
    Mixing
  };

  //! \brief 󥹥ȥ饯
  CEcaIAManager();
  //! \brief ǥȥ饯
  virtual ~CEcaIAManager();

  //! \brief  Ծ֤֤
  //! \return Ծ֡
  RunningStatus runningStatus() const;
  //! \brief  ꤵ줿ȥå̾Τ˥󥻥åȥåפ¸ߤ뤫ɤ֤
  //! \param  strTrackName ȥå̾Ρ
  //! \return ¸ߤƤ硢true֤
  bool isExisting(const QString& strTrackName) const;
  //! \brief  ꤵƤϤο֤
  //! \return Ϥο
  int numberOfInputs();
  //! \brief  ꤵƤϤο֤
  //! \return Ϥο
  int numberOfOutputs();
  //! \brief  Ͽ֤
  CSourceFormat soundSourceFormat() const;
  //! \brief  Хåե֤
  int bufferSize() const;
  //! \brief  Ͽꤹ롣
  void setSoundSourceFormat(const CSourceFormat& format);
  //! \brief  Хåեꤹ롣
  void setBufferSize(int nSize);
  //! \brief  ֤֤߰
  QTime pos();

public slots:
  //! \brief 󥻥åȥåפ򿷵롣
  //! \param strChainsetup 󥻥åȥå̾Ρ
  void slotCreateNewChainsetup(const QString& strChainsetup);
  //! \brief 󥻥åȥåפ˴롣
  void slotReleaseCurrentChainsetup();

  //! \brief 
  //! \param bRecord ϿꤵƤtrueꡣ
  void slotPlay(bool bRecord);
  //! \brief ߡ
  void slotStop();
  //! \brief ߡ
  //! \param bRecord ϿꤵƤtrueꡣ
  //! ˺ϤƤϡ̵뤵롣
  void slotPause(bool bRecord);
  //! \brief ߲
  void slotResume();
  //! \brief ޥݥѹ롣
  //! \param time ְ֡
  void slotSetMasterPosition(const QTime& time);
  //! \brief ֤ذư
  //! \param nSec ð֡
  void slotSetMasterPosition(int nSec);
  //! \brief ÿ󥻥åȥåפ᤹
  //! \param nSecond ᤷÿ
  void slotRewind(int nSecond);
  //! \brief ÿ󥻥åȥåפꤹ롣
  //! \param nSecond ꤷÿ
  void slotForward(int nSecond);
  //! \brief ߥå
  //! \param bWithPlaying ʤߥå󤹤trueꡣ
  //! \param strChainsetup ߥåѥ󥻥åȥå̾Ρ
  //! \param strFileName ߥåե̾Ρ
  void slotMixdown(bool bWithPlaying, 
                   const QString& strChainsetup, 
                   const QString& strFileName);

  //! \brief ȥåȤɲä롣
  //! \param TrackInfAdd Ȥɲäȥå
  void slotAddChain(const CTrackInf& TrackInfAdd);
  //! \brief 롣
  //! \param strTrackName ȥå̾Ρ
  void slotRemoveChain(const QString& strTrackName);
  //! \brief 롣
  //! \param nID ȥåID
  void slotRemoveChain(int nID);
  //! \brief ƤΥ롣
  void slotRemoveAllChains();
  //! \brief ƤϤ롣
  void slotRemoveAllInputs();
  //! \brief ƤνϤ롣
  void slotRemoveAllOutputs();

  //! \brief ץ쥤ХåǥХѹ
  void slotChangePlaybackDevice(const QString& strTrackName,
                                const QString& strDevice);
  //! \brief 쥳ǥ󥰥ǥХѹ
  void slotChangeRecordingDevice(const QString& strTrackName,
                                 const QString& strDevice);
  //! \brief ե̾ѹ
  void slotChangeFileName(const QString& strTrackName, const QString& strFileName);
  //! \brief ٥ѹ
  void slotChangeLevel(const QString& strTrackName, int nLevel);
  //! \brief ѥѹ
  void slotChangePan(const QString& strTrackName, int nPan);
  //! \brief ߥ塼Ⱦѹ
  void slotToggleMute(const QString& strTrackName, bool bMute);
  //! \brief Ͽѹ
  void slotToggleRec(const QString& strTrackName, bool bRec);
  //! \brief ϰѹ
  void slotChangeStartPosition(const QString& strTrackName, const QTime& StartPosition);
  //! \brief եåѹ
  void slotChangeOffset(const QString& strTrackName, const QTime& Offset);
  //! \brief Ĺѹ
  void slotChangeLength(const QString& strTrackName, const QTime& Length);

private:
  //! \brief ԡ󥹥ȥ饯ԡػߤ뤿ᡢprivate
  CEcaIAManager(const CEcaIAManager&);
  //! \brief 黻ҡػߤ뤿ᡢprivate
  CEcaIAManager& operator=(const CEcaIAManager&);

  //! ȥå٥
  QValueVector<CTrackInf> vTrackChains;
  //! Ewfѥȥå٥
  QValueVector<CTrackInf> vPrepareTrackChains;
  //! IDEcasoundλ(Finished)Ƚ˻ѡ
  int nTimerIDFinished;
  //! IDּ߰˻ѡ
  int nTimerIDCurrentPos;
  //! ޥݥ(ϰ())
  int nMasterPosition;
  //! ե̾Υꥹȡ
  QStringList strlTmpFiles;
  //! Ծ
  RunningStatus rStatus;
  //! Ͽեޥå
  CSourceFormat formatRecording;
  //! Хåե
  int           nBufferSize;

  //! \brief ȥå̾ΤФȥåΥǥ֤
  //! ꤵ줿ȥå̾ΤФȥå󤬸Ĥʤ硢
  //! -1֤롣
  //! \param strTrackName ȥå̾Ρ
  int getIndexByName(const QString& strTrackName) const;
  //! \brief ϥեȥǥХEcaControlerꤹ롣
  //! \param bRecord 쥳ǥ󥰤ͭˤʤäƤtrueꡣ
  //! \todo  too heavy
  //! ʣΥɥǥХбɬפ롣
  void setIOToCurrentChainsetup(bool bRecord);
  //! \brief ߥåѤEcaControlerꤹ롣
  //! \param bWithPlaying ʤߥå󤹤trueꡣ
  //! \param strFileName ߥåե̾Ρ
  void setMixdownIOToCurrentChainsetup(bool bWithPlaying, const QString& strFileName);
  //! \brief ޥ٥ȡ
  //! Ecasoundκλ(Finished)Ƚꤹ뤿Υޥ٥ȡ
  //! EcasoundΥץ֤Ƚꤹ뤿Υޥ٥ȡ
  void timerEvent(QTimerEvent* TimerEvent);
  //! \brief .ewfե롣
  //! \param strTrackName ȥå̾Ρ
  //! \param strFileName ե̾Ρ
  void writeEwf(const QString& strTrackName, const QString& strFileName);
  //! \brief .ewfե롣
  //! \param nIndex ȥåǥ
  //! \param strFileName ե̾Ρ
  void writeEwf(int nIndex, const QString& strFileName);
  //! \brief ȥåФɬפ.ewfեνԤ
  //! ȥåνԤ줿ȥåvPrepareTrackChains
  //! ˳Ǽ롣
  //! setIOToCurrentChainsetupΤ߸ƤӽФġ
  //! \param bIgnoresRecord ƥȥåΥ쥳ǥ󥰥ե饰̵뤹롣
  //! ߥåϡtrueꤹ롣
  //! \todo ߤϡΥȥåvPrepareTrackChains˳ǼƤ롣
  //! setIOToCurrentChainsetupvPrepareTrackChains
  //! Ȥ褦ˤ̵̤ʤʤ롣
  //! 硢vPrepareTrackChainsˤϡΤǤϤʤ
  //! EwfѤΥȥåǼФ褤
  void prepareTracks(bool bIgnoresRecord=false);
  //! \brief ȥå˹Ԥä.ewfեν򸵤᤹
  //! setIOToCurrentChainsetupΤ߸ƤӽФġ
  //! \todo setIOToCurrentChainsetupvPrepareTrackChains
  //! Ȥ褦ˤ餳δؿɬפʤʤ롣
  void destroyPreparings();
  //! \brief ƥݥե롣
  void removeTmpFiles();
  //! \brief ߤ
  void doDetailStopped();
  //! \brief  Ͻ
  //! slotPlayޤslotPause饳뤵롣
  //! \return 󥻥åȥåפСtrue֤
  bool start(bool bRecord);

private slots:
  //! \brief 
  //! \param strTrackName 򤷤ȥå̾Ρ
  //! ʣ򤷤硢','Ƕڤ롣
  void slotSelectChain(const QString& strTrackName);

signals:
  //! \brief ޥݥѹ줿ȯ륷ʥ롣
  void masterPositionChanged(const QTime&);
  //! \brief Ecasoundξ֤Finishedˤʤäȯ륷ʥ롣
  //! Stopped֤ˤʤäƤȯʤ
  void finished();
  //! \brief ˸֤߰Τ餻뤿ȯ륷ʥ롣
  void moved(const QTime&);
};

#endif
